@@ -42,6 +42,7 @@ class Daemon(FileSystemEventHandler):
         logging.info(f"New message detected: {event.src_path}")
 
         self.queue.put(Path(event.src_path))
+        time.sleep(1)  # wait for the file to be fully written to disk
         self.flush_queue()
 
     def flush_queue(self):
@@ -123,8 +124,9 @@ class Daemon(FileSystemEventHandler):
             stderr=PIPE,
         )
 
+        host, port = None, None
         for line in test_run.stdout.decode("utf-8").split("\n"):
-            # TODO convert this stuff to Walrus operators once that's more
+            # TODO (#3): convert this stuff to Walrus operators once that's more
             # supported by tools.
             host_match = self.host_re.match(line)
             if host_match:
